@@ -12,7 +12,7 @@ class ExtendedEnum(Enum):
         for x in cls:
             if s == x.name:
                 return x
-        raise ValueError("cannot find value [{}]".format(s))
+        raise ValueError(f"cannot find value [{s}]")
 
 
 def enum_type_to_list_str(e: Type[Enum]) -> List[str]:
@@ -28,18 +28,18 @@ def str_to_enum_value(s, e: Type[Enum]) -> Type[Enum]:
     for x in e:
         if s == x.name:
             return x
-    raise ValueError("cannot find value [{}]".format(s))
+    raise ValueError(f"cannot find value [{s}]")
 
 
 def str_to_enum_int(s: str, e: Type[Enum]) -> int:
     for x in e:
         if s == x.name:
             return x.value
-    raise ValueError("cannot find value [{}]".format(s))
+    raise ValueError(f"cannot find value [{s}]")
 
 
 def enum_int_to_name(i: int, e: Type[Enum]) -> str:
     for x in e:
         if i == x.value:
             return x.name
-    raise ValueError("cannot find value [{}]".format(i))
+    raise ValueError(f"cannot find value [{i}]")
